.. :changelog:

History
=======


0.6.8 (2020-02-29)
------------------
* Update multiple candidate match logic


0.6.7 (2020-02-29)
------------------
* cli: add nosave flag
* cli: do not automatically check for new shows after update
* cli: save after update (once)
* bug fix: show status not set for tvdb
* bug fix: update_all updates only first show
* allow force update with errors


0.6.6 (2019-12-05)
------------------
* Save shows only on changes


0.6.5 (2019-11-25)
------------------
* Update tvdb_api to 2.0


0.6.3 (2018-11-05)
------------------
* Update flotils
* Improve file saving


0.6.0b3 (2016-11-24)
--------------------
* Attempt fix for long running tvdb bug


0.6.0b1 (2016-05-15)
--------------------
* Fix cache file bug
* Improve locking


0.6.0b0 (2016-05-13)
--------------------
* Small debug output reduction
* Not running warning


0.6.0a0 (2016-05-13)
--------------------
* Change cli
* Change check/check_all interfaces (Use check_all like check before)
* Make StartStopable


0.5.4a0 (2016-05-05)
--------------------
* First release
